@@ -56,6 +56,7 @@
 #' }
 #' @import xts
 #' @import stats
+#' @import utils
 #' @export
 
 bekk_fit <- function(spec, data, QML_t_ratios = FALSE,
@@ -210,11 +211,13 @@ bekk_fit.bekk <- function(spec, data, QML_t_ratios = FALSE,
                  iter = params$iter,
                  likelihood_iter = params$likelihood_iter,
                  asymmetric = FALSE,
-                 data = data)
+                 data = data,
+                 spec = spec)
   class(result) <- c('bekkFit', 'bekk')
 
   result$AIC <- AIC(result)
   result$BIC <- BIC(result)
+  invisible(capture.output(result$Portmanteau.test <- portmanteau.test(result, lags = c(5,15,30))))
 
   return(result)
 }
@@ -362,11 +365,13 @@ bekk_fit.bekka <- function(spec, data, QML_t_ratios = FALSE,
                  likelihood_iter = params$likelihood_iter,
                  asymmetric = TRUE,
                  expected_signs = expected_signs,
-                 data = data)
+                 data = data,
+                 spec = spec)
   class(result) <- c('bekkFit', 'bekka')
 
   result$AIC <- AIC(result)
   result$BIC <- BIC(result)
+  invisible(capture.output(result$Portmanteau.test <- portmanteau.test(result, lags = c(5,15,30))))
 
   return(result)
 }
@@ -468,11 +473,13 @@ bekk_fit.dbekk <- function(spec, data, QML_t_ratios = FALSE,
                  iter = params$iter,
                  likelihood_iter = params$likelihood_iter,
                  asymmetric = FALSE,
-                 data = data)
+                 data = data,
+                 spec = spec)
   class(result) <- c('bekkFit', 'dbekk')
 
   result$AIC <- AIC(result)
   result$BIC <- BIC(result)
+  invisible(capture.output(result$Portmanteau.test <- portmanteau.test(result, lags = c(5,15,30))))
 
   return(result)
 }
@@ -583,11 +590,13 @@ bekk_fit.dbekka <- function(spec, data, QML_t_ratios = FALSE,
                  likelihood_iter = params$likelihood_iter,
                  asymmetric = TRUE,
                  expected_signs = expected_signs,
-                 data = data)
+                 data = data,
+                 spec = spec)
   class(result) <- c('bekkFit', 'dbekka')
 
   result$AIC <- AIC(result)
   result$BIC <- BIC(result)
+  invisible(capture.output(result$Portmanteau.test <- portmanteau.test(result, lags = c(5,15,30))))
 
   return(result)
 }
@@ -689,11 +698,13 @@ bekk_fit.sbekk <- function(spec, data, QML_t_ratios = FALSE,
                  iter = params$iter,
                  likelihood_iter = params$likelihood_iter,
                  asymmetric = FALSE,
-                 data = data)
+                 data = data,
+                 spec = spec)
   class(result) <- c('bekkFit', 'sbekk')
 
   result$AIC <- AIC(result)
   result$BIC <- BIC(result)
+  invisible(capture.output(result$Portmanteau.test <- portmanteau.test(result, lags = c(5,15,30))))
 
   return(result)
 }
@@ -804,11 +815,13 @@ bekk_fit.sbekka <- function(spec, data, QML_t_ratios = FALSE,
                  likelihood_iter = params$likelihood_iter,
                  asymmetric = TRUE,
                  expected_signs = expected_signs,
-                 data = data)
+                 data = data,
+                 spec = spec)
   class(result) <- c('bekkFit', 'sbekka')
 
   result$AIC <- AIC(result)
   result$BIC <- BIC(result)
+  invisible(capture.output(result$Portmanteau.test <- portmanteau.test(result, lags = c(5,15,30))))
 
   return(result)
 }
